# summarizer4u

Get your text summarized !

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install summarizer4u
```

## Usage

```python
from summarizer4u import summary

text = summary("your text to get summarized go here")

print(text)
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
